summaryrefslogtreecommitdiff
path: root/src/sound_asset.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/sound_asset.h')
-rw-r--r--src/sound_asset.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/sound_asset.h b/src/sound_asset.h
index 5c230e06..1e3553a0 100644
--- a/src/sound_asset.h
+++ b/src/sound_asset.h
@@ -127,10 +127,10 @@ public:
boost::shared_ptr<SoundAssetWriter> start_write (MXFMetadata const & metadata = MXFMetadata ());
/** Write details of this asset to a CPL stream.
* @param s Stream.
*/
- void write_to_cpl (std::ostream& s) const;
+ void write_to_cpl (xmlpp::Node* node) const;
bool equals (boost::shared_ptr<const Asset> other, EqualityOptions opt, boost::function<void (NoteType, std::string)> note) const;
@@ -127,10 +127,10 @@ public:
boost::shared_ptr<SoundAssetWriter> start_write (MXFMetadata const & metadata = MXFMetadata ());
- /** Write details of this asset to a CPL stream.
- * @param s Stream.
+ /** Write details of this asset to a CPL XML node.
+ * @param node Node.
*/